Discover Packages
github.com/416-C/terraform-registry-go
pkg
package
Version:
v0.0.0-...-8a3299a
Opens a new window with list of versions in this module.
Published: Nov 8, 2022
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Errors struct {
Errors []string `json:"errors"`
}
type Meta struct {
Limit int `json:"limit"`
CurrentOffset int `json:"current_offset"`
NextOffset int `json:"next_offset"`
PrevOffset int `json:"prev_offset"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.